Crate frunk_utils

source ·
Utilities for working with frunk.

Re-exports

Modules

Structs

  • The Func trait from frunk doesn’t take self as a parameter to call so there isn’t an easy way to get context from the surrounding scope. Here we define our own Poly wrapper and Func trait that does take self as a parameter so the caller can include whatever context they need.

Traits

  • Convenience functions for the caller to map between similarly-shaped types implementing [Generic] without having to explicitly call [Generic::from] and [Generic::into]
  • Convenience functions for the caller to map between similarly-shaped types implementing [LabelledGeneric] without having to explicitly call [LabelledGeneric::from] and [LabelledGeneric::into]